@@ -31,10 +31,10 @@ check_column_name <- function(column_name, table_name, exists, conn) {
   check_table_name(table_name, conn)
 
   column_exists <- column_exists(column_name, table_name, conn)
-  if (isTRUE(exists) && !column_exists) {
+  if (vld_true(exists) && !column_exists) {
     abort_chk("Can't find column `", column_name, "` in table `", table_name, "`.")
   }
-  if (isFALSE(exists) && column_exists) {
+  if (vld_false(exists) && column_exists) {
     abort_chk("`", column_name, "` must not already exist in table `", table_name, "`.")
   }
   column_name
@@ -42,8 +42,8 @@ check_column_name <- function(column_name, table_name, exists, conn) {
 
 check_column_blob <- function(column_name, table_name, conn) {
   check_column_name(column_name, table_name, exists = TRUE, conn)
-  is_blob <- is_column_blob(column_name, table_name, conn)
-  if (!is_blob) {
+  is_a_blob <- is_column_blob(column_name, table_name, conn)
+  if (!is_a_blob) {
     abort_chk("`", column_name, "` must be type BLOB.")
   }
   column_name
@@ -58,12 +58,30 @@ check_key <- function(table_name, key, conn) {
   key
 }
 
-check_flob_query <- function(x) {
+check_flob_query <- function(x, slob = FALSE) {
   if (is.null(unlist(x))) {
     abort_chk("Can't find flob in that location.")
   }
-  class(x) <- c("flob", "blob")
-  chk_flob(x)
+
+  if(vld_false(slob)){
+    class(x) <- c("flob", "blob")
+    chk_flob(x) # this is a problem when x is a blob and blob = FALSE
+  } else if (vld_true(slob)){
+    class(x) <- "blob"
+    flobr::chk_slob(x)
+    class(x) <- "list"
+    x <- blob::as_blob(x)
+    names(x) <- NULL
+  } else {
+    class(x) <- c("flob", "blob")
+    if(!vld_flob(x)){
+      class(x) <- c("blob")
+      chkor(flobr::chk_slob(x), chk_flob(x))
+      class(x) <- "list"
+      x <- blob::as_blob(x)
+      names(x) <- NULL
+    }
+  }
   invisible(x)
 }
 
